@@ -18,7 +18,9 @@ from fief.services.workspace_db import (
     WorkspaceDatabaseConnectionError,
 )
 
-LOCALHOST_HOST_PATTERN = re.compile(r"([^\.]+\.)?localhost(\d+)?", flags=re.IGNORECASE)
+LOCALHOST_HOST_PATTERN = re.compile(
+    r"([^\.]+\.)?localhost(\d+)?|127\.0\.0\.1", flags=re.IGNORECASE
+)
 
 
 class WorkspaceCreation:
@@ -58,7 +60,8 @@ class WorkspaceCreation:
         # Apply the database schema
         try:
             alembic_revision = self.workspace_db.migrate(
-                workspace.get_database_url(False), workspace.get_schema_name()
+                workspace.get_database_connection_parameters(False),
+                workspace.get_schema_name(),
             )
         except WorkspaceDatabaseConnectionError:
             await self.workspace_repository.delete(workspace)
